@@ -6,8 +6,9 @@
 // body for readability.
 #![allow(clippy::if_same_then_else)]
 
-use rayon::prelude::*;
 use std::{path::PathBuf, process::Command};
+
+use rayon::prelude::*;
 use version_check as rustc;
 
 struct TreeSitterParser {
@@ -335,6 +336,11 @@ fn main() {
             src_dir: "vendored_parsers/tree-sitter-typescript-src/typescript/src",
             extra_files: vec!["scanner.c"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-xml",
+            src_dir: "vendored_parsers/tree-sitter-xml-src/tree-sitter-xml/src",
+            extra_files: vec!["scanner.c"],
+        },
         TreeSitterParser {
             name: "tree-sitter-yaml",
             src_dir: "vendored_parsers/tree-sitter-yaml-src",
