@@ -3,11 +3,11 @@
 use std::cmp::Ordering;
 use std::collections::HashSet;
 
+use line_numbers::LineNumber;
 use rustc_hash::FxHashSet;
 
 use crate::{
     hash::DftHashMap,
-    lines::LineNumber,
     parse::syntax::{zip_repeat_shorter, MatchKind, MatchedPos},
 };
 
@@ -729,10 +729,11 @@ fn compact_gaps(
 mod tests {
     use std::iter::FromIterator;
 
-    use crate::{positions::SingleLineSpan, syntax::TokenKind};
+    use line_numbers::SingleLineSpan;
+    use pretty_assertions::assert_eq;
 
     use super::*;
-    use pretty_assertions::assert_eq;
+    use crate::syntax::TokenKind;
 
     #[test]
     fn test_calculate_before_context() {
