@@ -1,12 +1,14 @@
 //! Side-by-side (two column) display of diffs.
 
-use owo_colors::{OwoColorize, Style};
-
 use std::{
     cmp::{max, min},
     collections::HashSet,
 };
 
+use line_numbers::LineNumber;
+use line_numbers::SingleLineSpan;
+use owo_colors::{OwoColorize, Style};
+
 use crate::{
     constants::Side,
     display::context::all_matched_lines_filled,
@@ -16,10 +18,9 @@ use crate::{
         BackgroundColor,
     },
     hash::DftHashMap,
-    lines::{codepoint_len, format_line_num, LineNumber},
+    lines::{codepoint_len, format_line_num},
     options::{DisplayMode, DisplayOptions},
     parse::syntax::{zip_pad_shorter, MatchedPos},
-    positions::SingleLineSpan,
     summary::FileFormat,
 };
 
@@ -28,7 +29,7 @@ const SPACER: &str = " ";
 fn format_line_num_padded(line_num: LineNumber, column_width: usize) -> String {
     format!(
         "{:width$} ",
-        line_num.one_indexed(),
+        line_num.as_usize() + 1,
         width = column_width - 1
     )
 }
@@ -54,7 +55,7 @@ fn format_missing_line_num(
         style = style.dimmed();
     }
 
-    let num_digits = format!("{}", prev_num.one_indexed()).len();
+    let num_digits = prev_num.display().len();
     format!(
         "{:>width$} ",
         (if after_end { " " } else { "." }).repeat(num_digits),
@@ -594,14 +595,14 @@ pub fn print(
 
 #[cfg(test)]
 mod tests {
+    use pretty_assertions::assert_eq;
+
+    use super::*;
     use crate::{
         parse::guess_language::Language,
         syntax::{AtomKind, MatchKind, TokenKind},
     };
 
-    use super::*;
-    use pretty_assertions::assert_eq;
-
     #[test]
     fn test_width_calculations() {
         let line_nums = [(Some(1.into()), Some(10.into()))];
