@@ -1,17 +1,21 @@
 //! Apply colours and styling to strings.
 
+use std::cmp::{max, min};
+
+use line_numbers::LineNumber;
+use line_numbers::SingleLineSpan;
+use owo_colors::{OwoColorize, Style};
+use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
+
+use crate::parse::syntax::StringKind;
 use crate::{
     constants::Side,
     hash::DftHashMap,
-    lines::{byte_len, LineNumber},
+    lines::byte_len,
     options::DisplayOptions,
     parse::syntax::{AtomKind, MatchKind, MatchedPos, TokenKind},
-    positions::SingleLineSpan,
     summary::FileFormat,
 };
-use owo_colors::{OwoColorize, Style};
-use std::cmp::{max, min};
-use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
 
 #[derive(Clone, Copy, Debug)]
 pub enum BackgroundColor {
@@ -322,13 +326,14 @@ pub fn color_positions(
                 if syntax_highlight {
                     if let TokenKind::Atom(atom_kind) = highlight {
                         match atom_kind {
-                            AtomKind::String => {
+                            AtomKind::String(StringKind::StringLiteral) => {
                                 style = if background.is_dark() {
                                     style.bright_magenta()
                                 } else {
                                     style.magenta()
                                 };
                             }
+                            AtomKind::String(StringKind::Text) => {}
                             AtomKind::Comment => {
                                 style = style.italic();
                                 style = if background.is_dark() {
@@ -494,9 +499,10 @@ pub fn header(
 mod tests {
     const TAB_WIDTH: usize = 2;
 
-    use super::*;
     use pretty_assertions::assert_eq;
 
+    use super::*;
+
     #[test]
     fn split_string_simple() {
         assert_eq!(
