@@ -2,14 +2,16 @@
 
 use std::{env, ffi::OsStr, path::Path, path::PathBuf};
 
-use clap::{crate_authors, crate_description, crate_version, Arg, Command};
+use clap::{crate_authors, crate_description, Arg, Command};
 use const_format::formatcp;
 use crossterm::tty::IsTty;
+use itertools::Itertools;
 
 use crate::{
     display::style::BackgroundColor,
     exit_codes::EXIT_BAD_ARGUMENTS,
     parse::guess_language::{language_override_from_name, LanguageOverride},
+    version::VERSION,
 };
 
 pub const DEFAULT_BYTE_LIMIT: usize = 1_000_000;
@@ -83,7 +85,7 @@ impl Default for DiffOptions {
 fn app() -> clap::Command<'static> {
     Command::new("Difftastic")
         .override_usage(USAGE)
-        .version(crate_version!())
+        .version(VERSION.as_str())
         .about(crate_description!())
         .author(crate_authors!())
         .after_long_help(concat!(
@@ -95,6 +97,10 @@ fn app() -> clap::Command<'static> {
             "$ ",
             env!("CARGO_BIN_NAME"),
             " old/ new/\n\n",
+            "If you have a file with conflict markers, you can pass it as a single argument. Difftastic will diff the two conflicting file states.\n\n",
+            "$ ",
+            env!("CARGO_BIN_NAME"),
+            " file_with_conflicts.js\n\n",
             "Difftastic can also be invoked with 7 arguments in the format that GIT_EXTERNAL_DIFF expects.\n\n",
             "See the full manual at: https://difftastic.wilfred.me.uk/")
         )
@@ -150,7 +156,7 @@ fn app() -> clap::Command<'static> {
         )
         .arg(
             Arg::new("display").long("display")
-                .possible_values(["side-by-side", "side-by-side-show-both", "inline"])
+                .possible_values(["side-by-side", "side-by-side-show-both", "inline", "json"])
                 .default_value("side-by-side")
                 .value_name("MODE")
                 .env("DFT_DISPLAY")
@@ -160,7 +166,9 @@ side-by-side: Display the before file and the after file in two separate columns
 
 side-by-side-show-both: The same as side-by-side, but always uses two columns.
 
-inline: A single column display, closer to traditional diff display.")
+inline: A single column display, closer to traditional diff display.
+
+json: Output the results as a machine-readable JSON array with an element per file.")
         )
         .arg(
             Arg::new("color").long("color")
@@ -281,6 +289,7 @@ pub enum DisplayMode {
     Inline,
     SideBySide,
     SideBySideShowBoth,
+    Json,
 }
 
 #[derive(Eq, PartialEq, Debug)]
@@ -345,7 +354,7 @@ pub enum Mode {
         diff_options: DiffOptions,
         display_options: DisplayOptions,
         set_exit_code: bool,
-        language_overrides: Vec<(glob::Pattern, LanguageOverride)>,
+        language_overrides: Vec<(LanguageOverride, Vec<glob::Pattern>)>,
         /// The path where we can read the LHS file. This is often a
         /// temporary file generated by source control.
         lhs_path: FileArgument,
@@ -357,18 +366,27 @@ pub enum Mode {
         /// If this file has been renamed, the name it had previously.
         old_path: Option<String>,
     },
+    DiffFromConflicts {
+        diff_options: DiffOptions,
+        display_options: DisplayOptions,
+        set_exit_code: bool,
+        language_overrides: Vec<(LanguageOverride, Vec<glob::Pattern>)>,
+        path: FileArgument,
+        /// The path that we show to the user.
+        display_path: String,
+    },
     ListLanguages {
         use_color: bool,
-        language_overrides: Vec<(glob::Pattern, LanguageOverride)>,
+        language_overrides: Vec<(LanguageOverride, Vec<glob::Pattern>)>,
     },
     DumpTreeSitter {
         path: String,
-        language_overrides: Vec<(glob::Pattern, LanguageOverride)>,
+        language_overrides: Vec<(LanguageOverride, Vec<glob::Pattern>)>,
     },
     DumpSyntax {
         path: String,
         ignore_comments: bool,
-        language_overrides: Vec<(glob::Pattern, LanguageOverride)>,
+        language_overrides: Vec<(LanguageOverride, Vec<glob::Pattern>)>,
     },
 }
 
@@ -417,8 +435,8 @@ fn build_display_path(lhs_path: &FileArgument, rhs_path: &FileArgument) -> Strin
     }
 }
 
-fn parse_overrides_or_die(raw_overrides: &[String]) -> Vec<(glob::Pattern, LanguageOverride)> {
-    let mut res = vec![];
+fn parse_overrides_or_die(raw_overrides: &[String]) -> Vec<(LanguageOverride, Vec<glob::Pattern>)> {
+    let mut res: Vec<(LanguageOverride, Vec<glob::Pattern>)> = vec![];
     let mut invalid_syntax = false;
 
     for raw_override in raw_overrides {
@@ -426,7 +444,7 @@ fn parse_overrides_or_die(raw_overrides: &[String]) -> Vec<(glob::Pattern, Langu
             match glob::Pattern::new(glob_str) {
                 Ok(pattern) => {
                     if let Some(language_override) = language_override_from_name(lang_name) {
-                        res.push((pattern, language_override));
+                        res.push((language_override, vec![pattern]));
                     } else {
                         eprintln!("No such language '{}'", lang_name);
                         eprintln!("See --list-languages for the names of all languages available. Language overrides are case insensitive.");
@@ -450,7 +468,18 @@ fn parse_overrides_or_die(raw_overrides: &[String]) -> Vec<(glob::Pattern, Langu
         std::process::exit(EXIT_BAD_ARGUMENTS);
     }
 
-    res
+    res.into_iter()
+        .coalesce(
+            |(prev_lang, mut prev_globs), (current_lang, current_globs)| {
+                if prev_lang == current_lang {
+                    prev_globs.extend(current_globs);
+                    Ok((prev_lang, prev_globs))
+                } else {
+                    Err(((prev_lang, prev_globs), (current_lang, current_globs)))
+                }
+            },
+        )
+        .collect()
 }
 
 /// Parse CLI arguments passed to the binary.
@@ -503,57 +532,6 @@ pub fn parse_args() -> Mode {
         };
     }
 
-    let args: Vec<_> = matches.values_of_os("paths").unwrap_or_default().collect();
-    info!("CLI arguments: {:?}", args);
-
-    // TODO: document these different ways of calling difftastic.
-    let (display_path, lhs_path, rhs_path, old_path, in_vcs) = match &args[..] {
-        [lhs_path, rhs_path] => {
-            let lhs_arg = FileArgument::from_cli_argument(lhs_path);
-            let rhs_arg = FileArgument::from_cli_argument(rhs_path);
-            let display_path = build_display_path(&lhs_arg, &rhs_arg);
-            (display_path, lhs_arg, rhs_arg, None, false)
-        }
-        [display_path, lhs_tmp_file, _lhs_hash, _lhs_mode, rhs_tmp_file, _rhs_hash, _rhs_mode] => {
-            // https://git-scm.com/docs/git#Documentation/git.txt-codeGITEXTERNALDIFFcode
-            (
-                display_path.to_string_lossy().to_string(),
-                FileArgument::from_path_argument(lhs_tmp_file),
-                FileArgument::from_path_argument(rhs_tmp_file),
-                None,
-                true,
-            )
-        }
-        [old_name, lhs_tmp_file, _lhs_hash, _lhs_mode, rhs_tmp_file, _rhs_hash, _rhs_mode, new_name, _similarity] =>
-        {
-            // Rename file.
-            // TODO: where does git document these 9 arguments?
-
-            let old_name = old_name.to_string_lossy().to_string();
-            let new_name = new_name.to_string_lossy().to_string();
-
-            (
-                new_name,
-                FileArgument::from_path_argument(lhs_tmp_file),
-                FileArgument::from_path_argument(rhs_tmp_file),
-                Some(old_name),
-                true,
-            )
-        }
-        _ => {
-            if !args.is_empty() {
-                eprintln!(
-                    "error: Difftastic does not support being called with {} argument{}.\n",
-                    args.len(),
-                    if args.len() == 1 { "" } else { "s" }
-                );
-            }
-            eprintln!("USAGE:\n\n    {}\n", USAGE);
-            eprintln!("For more information try --help");
-            std::process::exit(EXIT_BAD_ARGUMENTS);
-        }
-    };
-
     let display_width = if let Some(arg_width) = matches.value_of("width") {
         arg_width
             .parse::<usize>()
@@ -566,6 +544,14 @@ pub fn parse_args() -> Mode {
         "side-by-side" => DisplayMode::SideBySide,
         "side-by-side-show-both" => DisplayMode::SideBySideShowBoth,
         "inline" => DisplayMode::Inline,
+        "json" => {
+            if env::var(format!("DFT_UNSTABLE")).is_err() {
+                eprintln!("JSON output is an unstable feature and its format may change in future. To enable JSON output, set the environment variable DFT_UNSTABLE=yes.");
+                std::process::exit(EXIT_BAD_ARGUMENTS);
+            }
+
+            DisplayMode::Json
+        }
         _ => {
             unreachable!("clap has already validated display")
         }
@@ -618,6 +604,90 @@ pub fn parse_args() -> Mode {
 
     let check_only = matches.is_present("check-only");
 
+    let diff_options = DiffOptions {
+        graph_limit,
+        byte_limit,
+        parse_error_limit,
+        check_only,
+        ignore_comments,
+    };
+
+    let args: Vec<_> = matches.values_of_os("paths").unwrap_or_default().collect();
+    info!("CLI arguments: {:?}", args);
+
+    // TODO: document these different ways of calling difftastic.
+    let (display_path, lhs_path, rhs_path, old_path, in_vcs) = match &args[..] {
+        [lhs_path, rhs_path] => {
+            let lhs_arg = FileArgument::from_cli_argument(lhs_path);
+            let rhs_arg = FileArgument::from_cli_argument(rhs_path);
+            let display_path = build_display_path(&lhs_arg, &rhs_arg);
+            (display_path, lhs_arg, rhs_arg, None, false)
+        }
+        [display_path, lhs_tmp_file, _lhs_hash, _lhs_mode, rhs_tmp_file, _rhs_hash, _rhs_mode] => {
+            // https://git-scm.com/docs/git#Documentation/git.txt-codeGITEXTERNALDIFFcode
+            (
+                display_path.to_string_lossy().to_string(),
+                FileArgument::from_path_argument(lhs_tmp_file),
+                FileArgument::from_path_argument(rhs_tmp_file),
+                None,
+                true,
+            )
+        }
+        [old_name, lhs_tmp_file, _lhs_hash, _lhs_mode, rhs_tmp_file, _rhs_hash, _rhs_mode, new_name, _similarity] =>
+        {
+            // Rename file.
+            // TODO: where does git document these 9 arguments?
+
+            let old_name = old_name.to_string_lossy().to_string();
+            let new_name = new_name.to_string_lossy().to_string();
+            let renamed = format!("Renamed from {} to {}", old_name, new_name);
+
+            (
+                new_name,
+                FileArgument::from_path_argument(lhs_tmp_file),
+                FileArgument::from_path_argument(rhs_tmp_file),
+                Some(renamed),
+                true,
+            )
+        }
+        [path] => {
+            let display_options = DisplayOptions {
+                background_color,
+                use_color,
+                print_unchanged,
+                tab_width,
+                display_mode,
+                display_width,
+                num_context_lines,
+                syntax_highlight,
+                in_vcs: true,
+            };
+
+            let display_path = path.to_string_lossy().to_string();
+            let path = FileArgument::from_path_argument(path);
+            return Mode::DiffFromConflicts {
+                display_path,
+                path,
+                diff_options,
+                display_options,
+                set_exit_code,
+                language_overrides,
+            };
+        }
+        _ => {
+            if !args.is_empty() {
+                eprintln!(
+                    "error: Difftastic does not support being called with {} argument{}.\n",
+                    args.len(),
+                    if args.len() == 1 { "" } else { "s" }
+                );
+            }
+            eprintln!("USAGE:\n\n    {}\n", USAGE);
+            eprintln!("For more information try --help");
+            std::process::exit(EXIT_BAD_ARGUMENTS);
+        }
+    };
+
     let display_options = DisplayOptions {
         background_color,
         use_color,
@@ -630,14 +700,6 @@ pub fn parse_args() -> Mode {
         in_vcs,
     };
 
-    let diff_options = DiffOptions {
-        graph_limit,
-        byte_limit,
-        parse_error_limit,
-        check_only,
-        ignore_comments,
-    };
-
     Mode::Diff {
         diff_options,
         display_options,
