@@ -2,22 +2,19 @@
 
 use std::collections::HashSet;
 
-use crate::hash::DftHashMap;
-use crate::options::DiffOptions;
-use crate::parse::guess_language as guess;
+use line_numbers::LinePositions;
 use tree_sitter as ts;
 use typed_arena::Arena;
 
-use crate::{
-    lines::NewlinePositions,
-    parse::syntax::{AtomKind, Syntax},
-};
-
-use super::syntax;
 use super::syntax::MatchedPos;
+use super::syntax::{self, StringKind};
+use crate::hash::DftHashMap;
+use crate::options::DiffOptions;
+use crate::parse::guess_language as guess;
+use crate::parse::syntax::{AtomKind, Syntax};
 
 /// A language may contain certain nodes that are in other languages
-/// and should be parsed as such (e.g. HTML <script> nodes containing
+/// and should be parsed as such (e.g. HTML `<script>` nodes containing
 /// JavaScript). This contains how to identify such nodes, and what
 /// languages we should parse them as.
 ///
@@ -114,6 +111,7 @@ extern "C" {
     fn tree_sitter_toml() -> ts::Language;
     fn tree_sitter_tsx() -> ts::Language;
     fn tree_sitter_typescript() -> ts::Language;
+    fn tree_sitter_xml() -> ts::Language;
     fn tree_sitter_yaml() -> ts::Language;
     fn tree_sitter_zig() -> ts::Language;
 }
@@ -244,6 +242,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     "string_literal",
                     "verbatim_string_literal",
                     "character_literal",
+                    "modifier",
                 ]
                 .into_iter()
                 .collect(),
@@ -999,6 +998,23 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 sub_languages: vec![],
             }
         }
+        Xml => {
+            let language = unsafe { tree_sitter_xml() };
+            TreeSitterConfig {
+                language,
+                // XMLDecl is the <?xml ...?> header, but the parser
+                // just treats it as a sequence of tokens rather than
+                // e.g. string subexpressions, so flatten.
+                atom_nodes: vec!["AttValue", "XMLDecl"].into_iter().collect(),
+                delimiter_tokens: (vec![("<", ">")]),
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendored_parsers/highlights/xml.scm"),
+                )
+                .unwrap(),
+                sub_languages: vec![],
+            }
+        }
         Yaml => {
             let language = unsafe { tree_sitter_yaml() };
             TreeSitterConfig {
@@ -1130,6 +1146,7 @@ fn tree_highlights(
             || name.starts_with("storage.type.")
             || name.starts_with("keyword.type.")
             || name == "tag"
+            || name == "constructor"
         {
             // TODO: this doesn't capture (type_ref) in Elm as that
             // applies to the parent node.
@@ -1309,7 +1326,7 @@ pub fn to_syntax<'a>(
     // highlighting and for more precise Syntax nodes where applicable.
     let subtrees = parse_subtrees(src, config, tree);
 
-    let nl_pos = NewlinePositions::from(src);
+    let nl_pos = LinePositions::from(src);
     let mut cursor = tree.walk();
 
     let mut error_count: usize = 0;
@@ -1409,7 +1426,7 @@ pub struct HighlightedNodeIds {
 fn all_syntaxes_from_cursor<'a>(
     arena: &'a Arena<Syntax<'a>>,
     src: &str,
-    nl_pos: &NewlinePositions,
+    nl_pos: &LinePositions,
     cursor: &mut ts::TreeCursor,
     error_count: &mut usize,
     config: &TreeSitterConfig,
@@ -1445,7 +1462,7 @@ fn all_syntaxes_from_cursor<'a>(
 fn syntax_from_cursor<'a>(
     arena: &'a Arena<Syntax<'a>>,
     src: &str,
-    nl_pos: &NewlinePositions,
+    nl_pos: &LinePositions,
     cursor: &mut ts::TreeCursor,
     error_count: &mut usize,
     config: &TreeSitterConfig,
@@ -1502,7 +1519,7 @@ fn syntax_from_cursor<'a>(
 fn list_from_cursor<'a>(
     arena: &'a Arena<Syntax<'a>>,
     src: &str,
-    nl_pos: &NewlinePositions,
+    nl_pos: &LinePositions,
     cursor: &mut ts::TreeCursor,
     error_count: &mut usize,
     config: &TreeSitterConfig,
@@ -1520,6 +1537,8 @@ fn list_from_cursor<'a>(
     let outer_close_content = "";
     let outer_close_position = nl_pos.from_offsets(root_node.end_byte(), root_node.end_byte());
 
+    // TODO: this should probably only allow the delimiters to be the
+    // first and last child in the list.
     let (i, j) = match find_delim_positions(src, cursor, &config.delimiter_tokens) {
         Some((i, j)) => (i as isize, j as isize),
         None => (-1, root_node.child_count() as isize),
@@ -1639,7 +1658,7 @@ fn list_from_cursor<'a>(
 fn atom_from_cursor<'a>(
     arena: &'a Arena<Syntax<'a>>,
     src: &str,
-    nl_pos: &NewlinePositions,
+    nl_pos: &LinePositions,
     cursor: &mut ts::TreeCursor,
     highlights: &HighlightedNodeIds,
     ignore_comments: bool,
@@ -1684,9 +1703,11 @@ fn atom_from_cursor<'a>(
     } else if highlights.keyword_ids.contains(&node.id()) {
         AtomKind::Keyword
     } else if highlights.string_ids.contains(&node.id()) {
-        AtomKind::String
+        AtomKind::String(StringKind::StringLiteral)
     } else if highlights.type_ids.contains(&node.id()) {
         AtomKind::Type
+    } else if node.kind() == "CharData" || node.kind() == "text" {
+        AtomKind::String(StringKind::Text)
     } else {
         AtomKind::Normal
     };
